@@ -9,7 +9,7 @@
 ## If this file is interactively sourced, the following are also needed to provide unexported functions:
 #source("util.data.R")
 
-info <- function(species=NULL, state=NULL, check.it=TRUE) {
+info <- function(species = NULL, state = NULL, check.it = TRUE) {
 
   ## Return information for one or more species in thermo()$OBIGT
   thermo <- get("thermo", CHNOSZ)
@@ -18,10 +18,10 @@ info <- function(species=NULL, state=NULL, check.it=TRUE) {
   ## If no species are requested, summarize the available data  20101129
   if(is.null(species)) {
     message("info: 'species' is NULL; summarizing information about thermodynamic data...")
-    message(paste("thermo()$OBIGT has", nrow(thermo$OBIGT[thermo$OBIGT$state=="aq", ]), "aqueous,",
+    message(paste("thermo()$OBIGT has", nrow(thermo$OBIGT[thermo$OBIGT$state == "aq", ]), "aqueous,",
       nrow(thermo$OBIGT), "total species"))
     message(paste("number of literature sources: ", nrow(thermo$refs), ", elements: ",
-      nrow(thermo$element), ", buffers: ", length(unique(thermo$buffer$name)), sep=""))
+      nrow(thermo$element), ", buffers: ", length(unique(thermo$buffer$name)), sep = ""))
     message(paste("number of proteins in thermo()$protein is", nrow(thermo$protein), "from",
       length(unique(thermo$protein$organism)), "organisms"))
     return()
@@ -48,8 +48,8 @@ info <- function(species=NULL, state=NULL, check.it=TRUE) {
     # State and species should be same length
     if(!is.null(state)) {
       lmax <- max(length(species), length(state))
-      state <- rep(state, length.out=lmax)
-      species <- rep(species, length.out=lmax)
+      state <- rep(state, length.out = lmax)
+      species <- rep(species, length.out = lmax)
     }
     # Loop over the species
     out <- sapply(seq_along(species), function(i) {
@@ -74,18 +74,18 @@ info.text <- function(ispecies, withsource = TRUE) {
   # a textual description of species name, formula, source, e.g.
   # CO2 [CO2(aq)] (SSW01, SHS89, 11.Oct.07)
   this <- get("thermo", CHNOSZ)$OBIGT[ispecies, ]
-  out <- paste(this$name, " [", this$formula, "(", this$state, ")", "]", sep="")
+  out <- paste(this$name, " [", this$formula, "(", this$state, ")", "]", sep = "")
   if(!withsource) return(out)
   sourcetext <- this$ref1
   ref2 <- this$ref2
-  if(!is.na(ref2)) sourcetext <- paste(sourcetext, ref2, sep=", ")
+  if(!is.na(ref2)) sourcetext <- paste(sourcetext, ref2, sep = ", ")
   date <- this$date
-  if(!is.na(date)) sourcetext <- paste(sourcetext, date, sep=", ")
+  if(!is.na(date)) sourcetext <- paste(sourcetext, date, sep = ", ")
   out <- paste(out, " (", sourcetext, ")", sep = "")
   return(out)
 }
 
-info.character <- function(species, state=NULL, check.protein=TRUE) {
+info.character <- function(species, state = NULL, check.protein = TRUE) {
   # Return the rownumbers of thermo()$OBIGT having an exact match of 'species' to
   # thermo()$OBIGT$[species|abbrv|formula] or NA otherwise
   # A match to thermo()$OBIGT$state is also required if 'state' is not NULL
@@ -93,7 +93,7 @@ info.character <- function(species, state=NULL, check.protein=TRUE) {
 
   thermo <- get("thermo", CHNOSZ)
   # Find matches for species name, abbreviation or formula
-  matches.species <- thermo$OBIGT$name==species | thermo$OBIGT$abbrv==species | thermo$OBIGT$formula==species
+  matches.species <- thermo$OBIGT$name == species | thermo$OBIGT$abbrv == species | thermo$OBIGT$formula == species
   # Since thermo()$OBIGT$abbrv contains NAs, convert NA results to FALSE
   matches.species[is.na(matches.species)] <- FALSE
   # Turn it in to no match if it's a protein in the wrong state
@@ -111,7 +111,7 @@ info.character <- function(species, state=NULL, check.protein=TRUE) {
         # Here we use a default state from thermo()$opt$state
         if(is.null(state)) state <- thermo$opt$state
         # Add up protein properties
-        eos <- protein.OBIGT(ip, state=state)
+        eos <- protein.OBIGT(ip, state = state)
         # The real assignment work 
         nrows <- suppressMessages(mod.OBIGT(eos))
         thermo <- get("thermo", CHNOSZ)
@@ -123,14 +123,14 @@ info.character <- function(species, state=NULL, check.protein=TRUE) {
   # Do we demand a particular state
   if(!is.null(state)) {
     # Special treatment for H2O: aq retrieves the liq
-    if(species %in% c("H2O", "water") & state=="aq") state <- "liq"
+    if(species %in% c("H2O", "water") & state == "aq") state <- "liq"
     # The matches for both species and state
     matches.state <- matches.species & state == thermo$OBIGT$state
     if(!any(matches.state)) {
       # The requested state is not available for this species
       available.states <- thermo$OBIGT$state[matches.species]
-      if(length(available.states)==1) a.s.verb <- "is" else a.s.verb <- "are"
-      a.s.text <- paste("'", available.states, "'", sep="", collapse=" ")
+      if(length(available.states) == 1) a.s.verb <- "is" else a.s.verb <- "are"
+      a.s.text <- paste("'", available.states, "'", sep = "", collapse = " ")
       message("info.character: requested state '", state, "' for ", species, 
         " but only ", a.s.text, " ", a.s.verb, " available")
       # Warn about looking for aqueous methane (changed to CH4) 20200707
@@ -146,25 +146,25 @@ info.character <- function(species, state=NULL, check.protein=TRUE) {
   # Processing for more than one match
   if(length(ispecies) > 1) {
     # If a single name matches, use that one (useful for distinguishing pseudo-H4SiO4 and H4SiO4) 20171020
-    matches.name <- matches.species & thermo$OBIGT$name==species
-    if(sum(matches.name)==1) ispecies.out <- which(matches.name)
+    matches.name <- matches.species & thermo$OBIGT$name == species
+    if(sum(matches.name) == 1) ispecies.out <- which(matches.name)
     else ispecies.out <- ispecies[1]  # otherwise, return only the first species that matches
     # Let user know if there is more than one state for this species
     mystate <- thermo$OBIGT$state[ispecies.out]
     ispecies.other <- ispecies[!ispecies %in% ispecies.out]
     otherstates <- thermo$OBIGT$state[ispecies.other]
     # For non-aqueous species, list other substances (isomers) in the same state 20210321
-    if(mystate != "aq" & sum(otherstates==mystate) > 0) {
-      otherstates[otherstates==mystate] <- thermo$OBIGT$name[ispecies.other[otherstates==mystate]]
+    if(mystate != "aq" & sum(otherstates == mystate) > 0) {
+      otherstates[otherstates == mystate] <- thermo$OBIGT$name[ispecies.other[otherstates == mystate]]
     }
     transtext <- othertext <- ""
-    # We count, but don't show the states for phase transitions (cr2, cr3, etc)
+    # We count, but don't show the states for polymorphic transitions (cr2, cr3, etc)
     istrans <- otherstates %in% c("cr2", "cr3", "cr4", "cr5", "cr6", "cr7", "cr8", "cr9")
-    if(mystate=="cr") {
-      # If we are "cr" we show the number of phase transitions
+    if(mystate == "cr") {
+      # If we are "cr" we show the number of polymorphic transitions
       ntrans <- sum(istrans)
-      if(ntrans == 1) transtext <- paste(" with", ntrans, "phase transition")
-      else if(ntrans > 1) transtext <- paste(" with", ntrans, "phase transitions")
+      if(ntrans == 1) transtext <- paste(" with", ntrans, "polymorphic transition")
+      else if(ntrans > 1) transtext <- paste(" with", ntrans, "polymorphic transitions")
     }
     myname <- NULL
     if(mystate != "aq") {
@@ -174,7 +174,7 @@ info.character <- function(species, state=NULL, check.protein=TRUE) {
     }
     otherstates <- unique(otherstates[!istrans])
     if(length(otherstates) == 1) othertext <- paste0("; also available in ", otherstates)
-    if(length(otherstates) > 1) othertext <- paste0("; also available in ", paste(otherstates, collapse=", "))
+    if(length(otherstates) > 1) othertext <- paste0("; also available in ", paste(otherstates, collapse = ", "))
     if(transtext != "" | othertext != "") {
       starttext <- paste0("info.character: found ", species, "(", mystate, ")")
       if(!is.null(myname)) starttext <- paste0(starttext, " [", myname, "]")
@@ -184,7 +184,7 @@ info.character <- function(species, state=NULL, check.protein=TRUE) {
   return(ispecies.out)
 }
 
-info.numeric <- function(ispecies, check.it=TRUE) {
+info.numeric <- function(ispecies, check.it = TRUE) {
   # From a numeric species index in 'ispecies' return the 
   #   thermodynamic properties and equations-of-state parameters
   thermo <- get("thermo", CHNOSZ)
@@ -219,9 +219,9 @@ info.numeric <- function(ispecies, check.it=TRUE) {
   # Identify any missing GHS values
   naGHS <- is.na(this[10:12])
   # A missing one of G, H or S can cause problems for subcrt calculations at high T
-  if(sum(naGHS)==1) {
+  if(sum(naGHS) == 1) {
     # calculate a single missing one of G, H, or S from the others
-    GHS <- as.numeric(GHS(as.character(this$formula), G = this[, 10], H = this[, 11], S = this[, 12], E_units=this$E_units))
+    GHS <- as.numeric(GHS(as.character(this$formula), G = this[, 10], H = this[, 11], S = this[, 12], E_units = this$E_units))
     message("info.numeric: ", colnames(this)[10:12][naGHS], " of ",
       this$name, "(", this$state, ") is NA; set to ", round(GHS[naGHS],2), " ", this$E_units, " mol-1")
     this[, which(naGHS) + 9] <- GHS[naGHS]
@@ -231,24 +231,24 @@ info.numeric <- function(ispecies, check.it=TRUE) {
   # Don't do it for the AD species 20190219
   if(check.it & this$model != "AD") {
     # Check GHS if they are all present
-    if(sum(naGHS)==0) calcG <- checkGHS(this)
-    # Check tabulated heat capacities against EOS parameters
-    calcCp <- checkEOS(this, this$model, "Cp")
+    if(sum(naGHS) == 0) calcG <- check.GHS(this, return.difference = FALSE)
+    # Check heat capacities in database against EOS parameters
+    calcCp <- check.EOS(this, this$model, "Cp", return.difference = FALSE)
     # Fill in NA heat capacity
     if(!is.na(calcCp) & is.na(this$Cp)) {
-      message("info.numeric: Cp of ", this$name, "(", this$state, ") is NA; set by EOS parameters to ", round(calcCp, 2), " ", this$E_units, " K-1 mol-1")
+      message("info.numeric: Cp\u00B0 of ", this$name, "(", this$state, ") is NA; set by EOS parameters to ", round(calcCp, 2), " ", this$E_units, " K-1 mol-1")
       this$Cp <- as.numeric(calcCp)
     } else if(isBerman) {
       # Calculate Cp for Berman minerals 20220208
       calcCp <- Berman(this$name)$Cp
       this$Cp <- calcCp
     }
-    # Check tabulated volumes - only for HKF model (aq species)
+    # Check volumes in database - only for HKF model (aq species)
     if(this$model %in% c("HKF", "DEW")) {
-      calcV <- checkEOS(this, this$model, "V")
+      calcV <- check.EOS(this, this$model, "V", return.difference = FALSE)
       # Fill in NA volume
       if(!is.na(calcV) & is.na(this$V)) {
-        message("info.numeric: V of ", this$name, "(", this$state, ") is NA; set by EOS parameters to ", round(calcV, 2), " cm3 mol-1")
+        message("info.numeric: V\u00B0 of ", this$name, "(", this$state, ") is NA; set by EOS parameters to ", round(calcV, 2), " cm3 mol-1")
         this$V <- as.numeric(calcV)
       }
     }
@@ -257,11 +257,11 @@ info.numeric <- function(ispecies, check.it=TRUE) {
   return(this)
 }
 
-info.approx <- function(species, state=NULL) {
+info.approx <- function(species, state = NULL) {
   # Returns species indices that have an approximate match of 'species'
   # to thermo$OBIGT$[name|abbrv|formula], possibly restricted to a given state
   thermo <- get("thermo", CHNOSZ)
-  if(!is.null(state)) this <- thermo$OBIGT[thermo$OBIGT$state==state, ]
+  if(!is.null(state)) this <- thermo$OBIGT[thermo$OBIGT$state == state, ]
   else this <- thermo$OBIGT
   # Only look for fairly close matches
   max.distance <- 0.1
@@ -271,23 +271,23 @@ info.approx <- function(species, state=NULL) {
   approx.species <- unique(c(approx.name, approx.abbrv, approx.formula))
   if(!is.na(approx.species[1])) {
     # Show the names of the species
-    if(length(approx.species)==1) {
+    if(length(approx.species) == 1) {
       message("info.approx: '", species, "' is similar to ", info.text(approx.species))
     } else {
       napprox.max <- 100
       exttext <- ":"
-      if(length(approx.species) > napprox.max) exttext <- paste(" (showing first ", napprox.max, ")", sep="")
+      if(length(approx.species) > napprox.max) exttext <- paste(" (showing first ", napprox.max, ")", sep = "")
       message("info.approx: '", species, "' is ambiguous; has approximate matches to ", 
         length(approx.species), " species", exttext)
       printout <- capture.output(print(thermo$OBIGT$name[head(approx.species, napprox.max)]))
-      message(paste(printout, collapse="\n"))
+      message(paste(printout, collapse = "\n"))
     }
     return(approx.species)
   }
   # If we got here there were no approximate matches
   # 20190127 look for the species in optional data files 
   for(opt in c("SLOP98", "SUPCRT92", "AD")) {
-    optdat <- read.csv(system.file(paste0("extdata/OBIGT/", opt, ".csv"), package="CHNOSZ"), as.is=TRUE)
+    optdat <- read.csv(system.file(paste0("extdata/OBIGT/", opt, ".csv"), package = "CHNOSZ"), as.is = TRUE)
     if(species %in% optdat$name) {
       message('info.approx: ', species, ' is in an optional database; use add.OBIGT("', opt, '", "', species, '") to load it')
       return(NA)
